<template>
  <div class="smart-adjust-card" v-change-height:smart-card-box v-if="!functype">
    <div class="smart-card-box">
      <card-group v-for="(card, cardIndex) in cardList" :key="cardIndex">
        <!-- 按钮组 -->
        <template v-slot:content>
          <div class="smart-adjust" v-if="card.key === 'SmartAdjust'">
            <div class="card-item" v-show="!card.hide">
              <!-- 左边 -->
              <div class="card-item-left">
                <!-- 功能标识 -->
                <div class="card-item-left-main">
                  <!-- 图标 -->
                  <div class="card-item-left-main-icon iconfont" :class="`iconfont-${card.icon.key}`" />
                  <div class="card-item-left-main-text">
                    <!-- 卡片名字 -->
                    <p class="card-item-left-main-text-name" v-text="card.name" />
                    <!-- 卡片描述 -->
                    <p class="card-item-left-main-text-describe" v-text="'空调会根据您的周围环境来推荐最佳的调节方法'" />
                  </div>
                </div>
              </div>
              <!-- 右边 -->
              <div class="card-item-right"></div>
            </div>
            <LoadingView :loaded="!isLoading" />
            <div class="card-main" v-show="!isLoading">
              <div class="smart-adjust-set-popup">
                <div class="popup-header">
                  <!-- <div class="recommended-Keys" v-for="(item, index) in recommendedKeys" :key="index">
                    <div :class="{ 'set-gray': isGray }" @click="isGray = !isGray">
                      {{ showRecommendedText(item) }}
                    </div>
                  </div> -->
                  <gree-check-group class="recommended-Keys" v-for="(item, index) in recommendedKeys" :key="index" v-model="patterns">
                    <gree-check-box :name="item">{{ btnText(item) }}</gree-check-box>
                  </gree-check-group>
                </div>
                <gree-button class="set-button" block round v-text="'一键开启'" @click="onClick" />
              </div>
            </div>
          </div>
        </template>
      </card-group>
    </div>
  </div>
</template>

<script>
import { row, col, list, Item, Button, CheckBox, CheckGroup } from 'gree-ui';
import { glyphs } from '@assets/iconfont/iconfont.json';
import BtnGroup from '@/components/BtnGroup/index';
import { types } from '@/store/types';
import CardGroup from '@/components/CardGroup/index';
import { mapState, mapGetters, mapMutations, mapActions } from 'vuex';
import PopupGroup from '@/components/Popup/index';
import { pluginHttp } from '@PluginInterface';
import LoadingView from '@components/LoadingView';

export default {
  name: 'smart-adjust-card',
  components: {
    [BtnGroup.name]: BtnGroup,
    [CardGroup.name]: CardGroup,
    [PopupGroup.name]: PopupGroup,
    [row.name]: row,
    [col.name]: col,
    [list.name]: list,
    [Item.name]: Item,
    [Button.name]: Button,
    [CheckBox.name]: CheckBox,
    [CheckGroup.name]: CheckGroup,
    LoadingView
  },
  data() {
    return {
      jsonMap: {
        1: 'CoolSvStTemMin',
        2: 'HumiSvStTemMin',
        4: 'HeatSvStTemMax',
        6: 'Heat3DSvStTemMax',
        7: 'Heat2SvStTemMax'
      },
      patterns: [],
      DEBUG: false,
      isShow: false,
      isGray: false,
      recommendedKeys: [],
      sendRecommendedValue: {},
      recommendedType: '',
      TemValue: 0,
      WdSpdValue: 0,
      ModValue: 0,
      sendObj: {},
      isLoading: true //是否显示loading
    };
  },
  computed: {
    ...mapState('control', {
      Mod: state => state.dataObject.Mod,
      CoolSvStTemMin: state => state.dataObject.CoolSvStTemMin || 18,
      HumiSvStTemMin: state => state.dataObject.HumiSvStTemMin || 18,
      HeatSvStTemMax: state => state.dataObject.HeatSvStTemMax || 18,
      Heat3DSvStTemMax: state => state.dataObject.Heat3DSvStTemMax || 18,
      Heat2SvStTemMax: state => state.dataObject.Heat2SvStTemMax || 18,
      HumiEnable: state => state.dataObject.HumiEnable,
      TemUn: state => state.dataObject.TemUn,
      mac: state => state.mac,
      functype: state => state.dataObject.functype
    }),

    ...mapGetters(['spFuncDefine', 'modTextKey', 'modCurrentStatusName', 'spModCurrentStatusName']),
    ...mapGetters('machine', ['statusMap', 'blindModelArr']),
    cardList() {
      if (!Object.keys(this.statusMap).length) return [];
      const result = this.spFuncDefine.map(model => {
        const identifier = model.identifier;
        if (!this.statusMap[identifier])
          return {
            icon: {},
            handler: () => {
              console.log('Undefined function');
            }
          };
        // 当前status定义
        const status = this.statusMap[identifier].status;
        // 取名称
        const defaultNameKey = `btn.${identifier}`;
        const footerKey = `footer.${identifier}`;
        const describeKey = `describe.${identifier}`;

        const statusNameText = status.name;
        const stateNameText = `${defaultNameKey}_${statusNameText}`;

        const name = stateNameText === this.$language(stateNameText) ? this.$language(defaultNameKey) : this.$language(stateNameText);
        const footer = this.parseStr(footerKey);
        const describe = this.parseStr(describeKey);
        // 图标
        const icon = glyphs.some(item => item.font_class === status.icon.key) ? status.icon : { key: 'undefined', type: 'off' };
        // 是否隐藏
        const hide = this.blindModelArr.includes(identifier);
        // 执行的方法
        const handler = (identifier, disable = false) => {
          disable || this.$stateMachine.nextStatus(identifier);
        };
        return { key: identifier, name, icon, hide, handler, footer, describe };
      });
      // return result.filter(value => {
      //   return value.key === 'SmartAdjust';
      // });
      return result;
    }
  },
  mounted() {
    this.getRecommendFields();
    setTimeout(() => {
      this.isLoading = false;
    }, 5000);
    this.recommendedKeys = this.DEBUG ? ['Mod', 'SetTem', 'WdSpd', 'AssHt', 'SvSt', 'Pow', 'Air', 'CleanState', 'Lig', 'StHt', 'Health', 'Tur'] : ''; // 测试数据
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP'
    }),
    ...mapMutations({
      setDataObject: types.SET_DATA_OBJECT,
      setState: types.CONTROL_SET_STATE
    }),
    ...mapActions({
      sendData: types.SEND_DATA
    }),
    parseStr(str) {
      //  没想好怎么处理，记得改
      if (str === 'describe.SvSt') {
        const { modText } = this;
        return this.$language(modText) + this.svstTextList + this[this.jsonMap[this.Mod]] + this.describeUnit;
      }
      return this.$language(str);
    },
    getRecommendFields() {
      pluginHttp('/gateway/portrait-recommend/portrait/recommend/personal', '', JSON.stringify({ mac: this.mac }), 'POST', 'iot7', '')
        .then(_res => {
          console.log(_res);
          let res = JSON.parse(_res).data.data.recommend;
          if (typeof res === 'string') {
            res = JSON.parse(res);
          }
          console.log('xxx-------', res);
          this.sendRecommendedValue = res;
          this.sendObj = JSON.parse(_res).data.data.extra;
          if (typeof this.sendObj === 'string') {
            this.sendObj = JSON.parse(this.sendObj);
          }
          const recommendedKeys = Object.keys(res);
          if (recommendedKeys.includes('SetTem')) {
            this.TemValue = res.SetTem;
          }
          if (recommendedKeys.includes('WdSpd')) {
            this.WdSpdValue = res.WdSpd;
          }
          if (recommendedKeys.includes('Mod')) {
            this.ModValue = res.Mod;
          }
          this.recommendedKeys = recommendedKeys;
          console.log('ssss,', recommendedKeys, this.recommendedKeys, this.TemValue);
        })
        .catch(err => console.error('xxx', err));
    },
    btnText(item) {
      const WdSpdMap = {
        0: '自动风',
        1: '低风',
        2: '中低风',
        3: '中风',
        4: '中高风',
        5: '高风'
      };
      const ModMap = {
        0: '自动',
        1: '制冷',
        2: '除湿',
        3: '送风',
        4: '制热'
      };
      if (item === 'SetTem') {
        return this.TemValue + '℃';
      } else if (item === 'WdSpd') {
        return WdSpdMap[this.WdSpdValue];
      } else if (item === 'Mod') {
        return ModMap[this.ModValue] + '模式';
      } else {
        return this.$language(`recommended.${item}`) + ' : ' + this.getRecommendType(item);
      }
    },
    filtreOrder() {
      this.patterns.forEach(item => {
        if (item === 'SlpMod') {
          this.$delete(this.sendObj, 'SwhSlp');
        }
        this.$delete(this.sendObj, item);
      });
    },
    onClick() {
      // console.log('xxx', this.sendObj);
      this.filtreOrder();
      this.sendData(this.sendObj);
      this.patterns = [];
      this.getRecommendFields();
      console.log('xxx2---', this.sendObj);
    },
    getRecommendType(item) {
      let result = '';
      this.sendRecommendedValue[item] ? (result = '开') : (result = '关');
      return result;
    }
  }
};
</script>

<style lang="scss">
.smart-adjust-card {
  position: relative;
  padding-bottom: 40px;
  .smart-adjust {
    width: 100%;
    .card-item {
      // $cardPadding: 30px;
      // height: calc(160px - #{$cardPadding} * 2;
      height: 140px;
      width: 100%;
      display: flex;
      justify-content: space-between;
      align-items: center;
      &-left {
        height: 100%;
        width: 100%;
        display: flex;
        justify-content: space-between;
        align-items: center;
        &-main {
          height: 100%;
          width: 100%;
          margin-left: 20px;
          display: flex;
          justify-content: flex-start;
          align-items: center;
          &-icon {
            $iconHeight: 68px;
            background-image: linear-gradient(180deg, #7fb5f6, #6da4e6);
            height: $iconHeight;
            width: $iconHeight;
            line-height: $iconHeight;
            margin-left: 42px;
            border-radius: 50%;
            font-size: 40px;
            color: #fff;
            text-align: center;
          }
          &-text {
            padding-left: 20px;
            &-name {
              font-size: 48px;
              color: #404657;
              // display: inline;
            }
            &-describe {
              color: #989898;
              font-size: 36px;
              display: inline;
            }
            &-footer {
              font-size: 36px;
              color: #989898;
            }
          }
        }
        &::after {
          width: 0px;
        }
      }
      &-right {
        width: auto;
        height: 100%;
        display: flex;
        justify-content: flex-start;
        align-items: center;
        &-edit {
          position: absolute;
          right: 58px;
          font-size: 46px;
        }
      }
    }
    .card-main {
      width: 100%;
      .smart-adjust-set-popup {
        overflow: hidden;
        width: 100%;
        padding-bottom: 50px;
        .popup-header {
          display: flex;
          flex-wrap: wrap;
          justify-content: space-around;
          .gree-check-base-box {
            width: 280px;
            height: 80px;
            line-height: 80px;
            font-size: 44px;
            border: none;
            padding: 0;
            text-align: center;
            background-color: rgba(152, 152, 152, 0.1);
            border-radius: 40px;
            margin-top: 45px;
            margin-bottom: 45px;
          }
          .gree-check-base-box.is-checked {
            opacity: 0.4 !important;
            color: #989898;
            .gree-tag {
              display: none;
            }
          }
          .gray {
            background-color: gray;
          }
        }
        .set-button {
          width: 434px;
          height: 83px;
          line-height: 89px;
          text-align: center;
          font-size: 40px;
          opacity: 1;
          color: #fff;
          background-color: #77a7e0;
          border-radius: 47px;
          margin-top: 90px;
          margin: 0 auto;
        }
      }
    }
  }
}
</style>
